@@ -1,12 +1,10 @@
-package App::GetoptPanjangUtils;
+package App::GetoptLongUtils;
 
 our $DATE = '2016-09-14'; # DATE
-our $VERSION = '0.001'; # VERSION
-
-use 5.010001;
+our $VERSION = '0.002'; # VERSION
 
 1;
-# ABSTRACT: Collection of CLI utilities related to Getopt::Panjang
+# ABSTRACT: Collection of CLI utilities related to Getopt::Long
 
 __END__
 
@@ -16,16 +14,16 @@ __END__
 
 =head1 NAME
 
-App::GetoptPanjangUtils - Collection of CLI utilities related to Getopt::Panjang
+App::GetoptLongUtils - Collection of CLI utilities related to Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.001 of App::GetoptPanjangUtils (from Perl distribution App-GetoptLongUtils), released on 2016-09-14.
+This document describes version 0.002 of App::GetoptLongUtils (from Perl distribution App-GetoptLongUtils), released on 2016-09-14.
 
 =head1 DESCRIPTION
 
 This distribution provides the following command-line utilities related to
-L<Getopt::Panjang>:
+L<Getopt::Long>:
 
 =over
 
@@ -51,7 +49,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Getopt::Panjang>
+L<Getopt::Long>
 
 =head1 AUTHOR
 
